@@ -3,6 +3,7 @@ package tokencmd
 import (
 	"bytes"
 	"encoding/json"
+	"encoding/pem"
 	"errors"
 	"fmt"
 	"net/http"
@@ -141,11 +142,11 @@ func TestRequestToken(t *testing.T) {
 		}
 	}
 
+	initialRequest := req{}
+
 	initialHead := req{"", http.MethodHead, "/"}
 	initialHeadResp := resp{http.StatusInternalServerError, "", nil} // value of status is ignored
 
-	initialRequest := req{}
-
 	basicChallenge1 := resp{401, "", []string{"Basic realm=foo"}}
 	basicRequest1 := req{"Basic bXl1c2VyOm15cGFzc3dvcmQ=", "", ""} // base64("myuser:mypassword")
 	basicChallenge2 := resp{401, "", []string{"Basic realm=seriously...foo"}}
@@ -432,7 +433,7 @@ func TestRequestToken(t *testing.T) {
 
 	for k, tc := range testcases {
 		i := 0
-		s := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, req *http.Request) {
+		s := httptest.NewTLSServer(http.HandlerFunc(func(w http.ResponseWriter, req *http.Request) {
 			defer func() {
 				if err := recover(); err != nil {
 					t.Errorf("test %s panicked: %v", k, err)
@@ -480,8 +481,13 @@ func TestRequestToken(t *testing.T) {
 		defer s.Close()
 
 		opts := &RequestTokenOptions{
-			ClientConfig: &restclient.Config{Host: s.URL},
-			Handler:      tc.Handler,
+			ClientConfig: &restclient.Config{
+				Host: s.URL,
+				TLSClientConfig: restclient.TLSClientConfig{
+					CAData: pem.EncodeToMemory(&pem.Block{Type: "CERTIFICATE", Bytes: s.Certificate().Raw}),
+				},
+			},
+			Handler: tc.Handler,
 			OsinConfig: &osincli.ClientConfig{
 				ClientId:     openShiftCLIClientID,
 				AuthorizeUrl: oauthdiscovery.OpenShiftOAuthAuthorizeURL(s.URL),
